@@ -1,5 +1,5 @@
 `slope` <-
-function(ogg, level=0.95){
+function(ogg, conf.level=0.95){
 #2/10/03; 21/10/03; 4/11/03; 24/02/04; 25/02/04; 28/04/06
 #Ad ogni chiamata di grep()  stato aggiunto l'argomento extended=F per consentire Z=log(x)
 #returns Est., St.Err., t value and Conf Interv (1-level) for the slopes
@@ -24,9 +24,9 @@ function(ogg, level=0.95){
             cof.out<-M%*%cof 
             cov.out<-M%*%covv%*%t(M)
             se.out<-sqrt(diag(cov.out))
-            k<-abs(qnorm((1-level)/2))*se.out
+            k<-abs(qnorm((1-conf.level)/2))*se.out
             ris<-cbind(cof.out,se.out,(cof.out/se.out),(cof.out-k),(cof.out+k))
-            cin<-paste("CI","(",level*100,"%",")",c(".l",".u"),sep="")
+            cin<-paste("CI","(",conf.level*100,"%",")",c(".l",".u"),sep="")
             #se la left slope  nulla....
             if(identical(length(ind),length(grep(nomeZ[i], nomeU, extended=FALSE)))){
                     ris<-rbind(c(0,rep(NA,(ncol(ris)-1))),ris)}
